function T=RndMultiT(mu,Sigma,df)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PURPOSE:     Random number generator for the k-variate student-t distribution with mean mu, covariance matrix
%              Sigma/(df-2) and df degrees of freedom
%
% INPUT:       mu       (k-by-1)        
%              Sigma    (k-by-k)            
%              df       (Scalar)            
%
% OUTPUT:      T        (k-by-1)    A draw from the multivariate student-t.          
%
% AUTHOR:      Mattias Villani, Research Department, Sveriges Riksbank and
%              Department of Statistics, Stockholm University. 
%              E-mail: mattias.villani@riksbank.se
%
% REVISED:     2005-11-03
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
mu=mu(:);
k=length(mu);
C=chol(Sigma)';
z=randn(k,1);
x=chi2rnd(df);

T=mu+C*z/sqrt(x/df); % Bauwens et al: T=mu+C*z/sqrt(x/(df-2));